#include "ast3d.h"

/*
** bool AstMissile::DetermineVisibility( void )
**
** The AstMissile class enhances the base AstObject's
** DetermineVisibility() function by first checking to see
** if it is in flight or not.
*/
bool AstMissile::DetermineVisibility( void )
{
   if ( InFlight() ) {
      AstObject::DetermineVisibility();
   }
   else {
      SetFlag( ofVisible, false );
   }
   return CheckFlag( ofVisible );
}

/*
** void AstMissile::DoSomething( void )
**
** The AstMissile's DoSomething() function flies the missile on
** its course via drifting, and checks to make sure that the
** missile has not lived past its expected lifespan.
*/
void AstMissile::DoSomething( void )
{
   if ( InFlight() ) {
      if ( ++alive > lifetime ) {
         FizzleOut();
      }
      else {
         RotateAroundX( 100 );
         RotateAroundY( 100 );
         RotateAroundZ( 100 );
         AstDrifter::Drift();
      }
   }
}

/*
** void AstMissile::FizzleOut( void )
**
** This function kills the missile, i.e. prevents it from
** flying any more by setting its "inflight" flag to false and
** alive time to 0.
*/
void AstMissile::FizzleOut( void )
{
  inflight = false;
  alive    = 0;
  SetFlag( ofSolid, false );
}

/*
** void AstMissile::YouHit( AstObject * )
**
** The default behaviour for a missile when it strikes another
** object is to simply fizzle out.
*/
void AstMissile::YouHit( AstObject * )
{
   FizzleOut();
}
