#ifndef __AST3D_H
#define __AST3D_H

/*
** Load commonly used library header files
*/
#include <bios.h>
#include <conio.h>
#include <dos.h>
#include <math.h>
#include <stdlib.h>
#include <stdio.h>
#include <string.h>
#include <time.h>

/*
** Compiler specific constructs
*/
#ifdef __BORLANDC__
#  define DISABLE()            disable()
#  define ENABLE()             enable()
#  define OUTPORTB(a,b)        outportb(a,b)
#  define INPORTB(a)           inportb(a)
#  define REGISTERWORD( r, a ) ( r.x.a )
#  ifdef __INLINING__
#    pragma inline
#    define A asm
     A .386
#  endif
#  define INT86( a, b, c )     int86( a, b, c )
#  define INT86X( a, b, c, d ) int86x( a, b, c, d )
#else
#  define DISABLE()            _disable()
#  define ENABLE()             _enable()
#  define OUTPORTB(a,b)        outp(a,b)
#  define INPORTB(a)           inp(a)
#  define REGISTERWORD( r, a ) ( r.w.a )
#  define INT86( a, b, c )     int386( a, b, c )
#  define INT86X( a, b, c, d ) int386x( a, b, c, d )
#  define M_PI 3.141592
inline short int random( short int val )
{
   return ( short ) (((long)rand()*val)/(RAND_MAX+1));
}
#endif

/*
** Load header files for other
*/
#include "atype.h"
#include "amath.h"
#include "apalette.h"
#include "avga.h"
#include "agamept.h"

#include "ainput.h"
#include "akbd.h"
#include "amouse.h"
#include "ajoy.h"
#include "athrustm.h"

#include "atexmap.h"
#include "atri.h"
#include "aobjdef.h"
#include "aobject.h"
#include "atrig.h"
#include "acamera.h"
#include "aworld.h"

#include "adrifter.h"
#include "amissile.h"
#include "aplayer.h"
#include "aast.h"

struct AstConfig
{
   bool joystick, rcs, wcs;
   bool texturing;
   bool mouse;
};

const int PLAY_FIELD_WIDTH = 50;

/*
** Support functions
*/
void AstEnd( void );
void AstInit( int argc, const char *argv[] );
void AstLibEnd( void );
void AstLibInit( void );
void AstFatal( const char *msg );

/*
** Variable declarations
*/
const AstFixedpoint_t near_z = AstConvertToFix( 4 );

extern AstVGA       *vga;
extern AstConfig     config;
extern AstTrigTable *trig_table;

extern AstPlayer    *player;
extern AstWorld      world;
extern AstCamera     camera;

extern AstGameport  *gameport;
extern AstKeyboard  *keyboard;
extern Ast2DInputDevice *inputdevice2d;
extern AstRCS       *rcs;
extern AstWCS       *wcs;

extern const AstMatrix4x3 *world_to_camera_matrix;

#endif
