#ifndef __AVGA_H
#define __AVGA_H

class AstTextureMap;

const int SCREEN_WIDTH  = 320;
const int SCREEN_HEIGHT = 200;

struct AstScreenVertex
{
   int X, Y;
};

class AstVGA
{
  protected:
    int         frames;
    AstPalette *palette;
    char       *drawbuffer;
    const AstTextureMap *current_map;

    void SetCurrentMap( const AstTextureMap *m ) { current_map = m; }

    void SetupDefaultPalette( void );
    void SetPalette( AstPalette &palette );

    void TMHLine( AstFixedpoint_t x1, AstFixedpoint_t x2,
                  AstFixedpoint_t u1, AstFixedpoint_t u2,
                  AstFixedpoint_t v1, AstFixedpoint_t v2,
                  int y );

    void FB_Triangle( int x1, int y1, int x2, int y23, int x3, int   , unsigned char color );

    void FB_TMTriangle( int x1, int y1,  int u1, int v1,
                        int x2, int y23, int u2, int v2,
                        int x3, int    , int u3, int v3,
                        const AstTextureMap &map );

  public:
    AstVGA( void );
   ~AstVGA();

    void BlitPage( void );
    void ClearScreen( unsigned char color );
    int  GetFrames( void ) const { return frames; }

    void HLine( int x1, int x2, int y, unsigned char color );
    void VLine( int x, int y1, int y2, unsigned char color );

    void Triangle( const AstScreenVertex &a, const AstScreenVertex &b, const AstScreenVertex &c, unsigned char color );
    void TextureMappedTriangle( const AstScreenVertex &a, const AstScreenVertex &b, const AstScreenVertex &c,
                                const AstScreenVertex &ta, const AstScreenVertex &tb, const AstScreenVertex &tc,
                                const AstTextureMap *texture_map );

    void StartGraphics( void );
    void StopGraphics( void );
};

#endif
