#include "ast3d.h"

/*
** AstPalette::AstPalette( const char *filename )
**
** This is the constructor for the AstPalette class.  It loads the
** specified PAL file from disk
*/
AstPalette::AstPalette( const char *filename )
{
   valid = Load( filename );
}

/*
** void AstPalette::InitPaletteBlock( int color, r1, g1, b1, r2, g2, b2 )
**
** This routine initializes the palette block denoted by "color" to have
** the range of values from rgb(1) to rgb(2).
*/
void AstPalette::InitPaletteBlock( int color, float r1, float g1, float b1,
                                              float r2, float g2, float b2 )
{
float dr = ( r2 - r1 ) * 4.0,
      dg = ( g2 - g1 ) * 4.0,
      db = ( b2 - b1 ) * 4.0;
float r = r1 * 64.0,
      g = g1 * 64.0,
      b = b1 * 64.0;

   for ( int i = 0; i < 16; i++ ) {
      data[color*16+i][0] = ( unsigned char ) r;
      data[color*16+i][1] = ( unsigned char ) g;
      data[color*16+i][2] = ( unsigned char ) b;
      r += dr;
      g += dg;
      b += db;
   }
}

/*
** bool AstPalette::Load( const char *filename )
**
** This routine loads the palette information from a PAL file specified
** by filename.
*/
bool AstPalette::Load( const char *filename )
{
FILE *fp;

   if ( ( fp = fopen( filename, "rt" ) ) != 0 ) {
      for ( int i = 0; i < 16; i++ ) {
         char linebuffer[80];
         float r1, r2, g1, g2, b1, b2;

         if ( fgets( linebuffer, sizeof( linebuffer ), fp ) )
            sscanf( linebuffer, "%f,%f,%f to %f,%f,%f", &r1, &g1, &b1, &r2, &g2, &b2 );
         else
            AstFatal( "Unexpected EOF reading palette" );

         InitPaletteBlock( i, r1, g1, b1, r2, g2, b2 );
      }
      fclose( fp );
      return true;
   }
   else {
      return false;
   }
}
